module.exports = function(grunt) {

	require('load-grunt-tasks')(grunt);

	// todo: вынести параметры в начало файла
	// var param = {};
	// param.buildDir = './build';
	// param.cssDir = './css';
	// param.jsDir = './js';

	grunt.initConfig({

		// очистка временной директорий и удаление ранее минифицированных файлов
		clean: {
			js: ['build/*', 'js/main.min.js'],
			css: ['build/*', 'css/main.min.css'],
			all: ['build/*', 'js/main.min.js', 'css/main.min.css']
		},

		// объединяем js файлы
	    concat: {

            dist: {
                src: ['js/*.js'],
                dest: 'build/merge.js',
            }
        },

	    // минификация js
	    uglify: {
			dev: {
				options: {
					mangle: true,
					comments: false,
					compress: {
						dead_code: true
					}
				},
				// назначение : [источник]
				files: {
			        'js/main.min.js': ['build/merge.js']
			    }
			}
		},

        // очистка css от не используемых стилей
        // content: массив путей с шаблонами темы и js файлами, в которых могут быть объявлены стили
        // whitelist: стили истключенные из обработки. !НЕ работает - баг в grunt-purgecss
        // вместо whitelist используйте комментарии в стилях: /*! purgecss start ignore */ и /*! purgecss end ignore */
        purgecss: {
			my_target: {
				options: {
					content: ['./inc/*.tpl', './modules/**/*.tpl', './plugins/**/*.tpl', './*.tpl', './js/*.js', '../../datas/html/*.html', '../../inc/botan/*.js', '../../js/*.js'],
					whitelist: ['advantages', 'advantages-title', 'advantages-detail', 'pin-cta', 'pinned', 'page-cta', 'page-how', 'page-how-step', 'step-num']
				},
				// назначение : [источник]
				files: {
					'build/main-clean.min.css': ['build/main.min.css']
				}
			}
	    },

        // минификация css
        // подробнее, опции: https://github.com/jakubpawlowicz/clean-css#how-to-use-clean-css-api
        cssmin: {
			options: {
				processImport: false,
				compatibility: 'ie9',
				mergeIntoShorthands: false,
				mergeMedia: true,
				specialComments: 'all',
				removeEmpty: true,
				removeQuotes: true,
				removeWhitespace: true,
				removeDuplicateFontRules: true,
				removeDuplicateMediaBlocks: true,
				removeDuplicateRules: true,
				replaceMultipleZeros: true,
				tidyAtRules: true,
				tidyBlockScopes: true,
				tidySelectors: true,
				roundingPrecision: -1
			},
			// назначение : [источник]
			target: {
				files: {
				  'build/main.min.css': ['css/*.css', 'css/!*.min.css']
				}
			}
		},

		// удаляем комментарии в css, если остались whitelist от purgecss
		stripCssComments: {
	        options: {
	        	preserve: false // Removes important comments
	        },
	        // назначение : [источник]
	        dist: {
	            files: {
	                'css/main.min.css': 'build/main-clean.min.css'
	            }
	        }
    	}
	});

	grunt.loadNpmTasks('grunt-purgecss');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-contrib-cssmin');
	grunt.loadNpmTasks('grunt-contrib-clean');

	grunt.registerTask('js', ['clean:js', 'concat', 'uglify']);
	grunt.registerTask('css', ['clean:css', 'cssmin', 'purgecss', 'stripCssComments']);
	grunt.registerTask('default', ['clean:all', 'cssmin', 'purgecss', 'stripCssComments', 'concat', 'uglify']);
};